==> vokoscreen_2.0.5~beta.orig.tar.gz: vokoscreen-2.0.5-beta/language/vokoscreen_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Wyślij ostatnie nagranie</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Wyślij jedno lub kilka nagrań</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Nagranie wideo znajduje się w załączniku</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Wybierz jeden lub wiele plików</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Bez ramki</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Ramka</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Urządzenie zajęte</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Wybierz kamerę</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nie nagrywaj kursora myszy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ścieżka wideo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Zminimalizuj vokoscreen podczas nagrywania</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Czas nagrywania</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Rozmiar w KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Rozmiar nagrywanego obrazu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ustawiona liczba klatek</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odliczanie</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Odtwórz ostatnie nagranie</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Wyślij nagranie</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktualna liczba klatek na sekundę</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Urządzenie %1 jest zajęte</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Strona domowa</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Lista mailingowa</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Wsparcie</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Programista</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Klatki</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darowizna</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program nagrywający</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kod źródłowy</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokazuj w tacce systemowej</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Dostępna jest nowa wersja</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodek wideo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodek audio</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Wyślij ostatnie nagranie</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Wyślij jedno lub kilka nagrań</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Nagranie wideo znajduje się w załączniku</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Wybierz jeden lub wiele plików</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>Bez ramki</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Ramka</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nie nagrywaj kursora myszy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ścieżka wideo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Zminimalizuj vokoscreen podczas nagrywania</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Czas nagrywania</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Rozmiar w KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Rozmiar nagrywanego obrazu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ustawiona liczba klatek</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odliczanie</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Odtwórz ostatnie nagranie</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Wyślij nagranie</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktualna liczba klatek na sekundę</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Urządzenie %1 jest zajęte</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Strona domowa</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Lista mailingowa</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Wsparcie</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Programista</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Klatki</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darowizna</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program nagrywający</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kod źródłowy</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokazuj w tacce systemowej</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Dostępna jest nowa wersja</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodek wideo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodek audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Wybierz kamerę</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
